NAME

Role::HasPayload::Merged - merge autogenerated payload with constructor-specified payload

VERSION

version 0.006

SYNOPSIS

package Example;
use Moose;

with qw(Role::HasPayload::Merged);

sub Payload { 'Role::HasPayload::Meta::Attribute::Payload' }

has height => (
  is => 'ro',
  traits   => [ Payload ],
);

has width => (
  is => 'ro',
  traits   => [ Payload ],
);

has color => (
  is => 'ro',
);

...then...

my $example = Example->new({
  height  => 10,
  width   => 20,
  color   => 'blue',
  payload => { depth => 30 },
});

$example->payload; # { height => 10, width => 20, depth => 30 }

DESCRIPTION

Role::HasPayload::Merged provides a payload method and a payload attribute. It computes the result of the payload method when it's called, first by gathering the values of attributes marked with Role::HasPayload::Meta::Attribute::Payload, then by merging in the contents of the payload attribute (provided at construction).

If an entry in the constructor-provided payload already exists in the autogenerated payload, a warning is issued and the autogenerated value is used.

For a bit more on the autogenerated payload, see Role::HasPayload::Auto.

This role is especially useful when combined with Role::HasMessage::Errf.

AUTHOR

Ricardo Signes <rjbs@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.